import { useScript as _useScript } from "@unhead/vue";
import { injectHead, useNuxtApp } from "#imports";
export function useScript(input, options) {
  input = typeof input === "string" ? { src: input } : input;
  options = options || {};
  const nuxtApp = useNuxtApp();
  const script = _useScript(input, {
    async transform(script2) {
      await nuxtApp.hooks.callHook("scripts:transform", { script: script2, options });
      return script2;
    },
    ...options
  });
  if (import.meta.dev) {
    let syncScripts = function() {
      nuxtApp._scripts[script.$script.id] = payload;
      nuxtApp.hooks.callHook("scripts:updated", { scripts: nuxtApp._scripts });
    };
    const payload = {
      key: input.key || input.src,
      src: input.src,
      $script: null,
      events: []
    };
    nuxtApp._scripts = nuxtApp._scripts || {};
    if (!nuxtApp._scripts[script.$script.id]) {
      const head = injectHead();
      head.hooks.hook("script:updated", (ctx) => {
        if (ctx.script.id !== script.$script.id)
          return;
        payload.events.push({
          type: "status",
          status: ctx.script.status,
          at: Date.now()
        });
        payload.$script = script.$script;
        syncScripts();
      });
      head.hooks.hook("script:instance-fn", (ctx) => {
        if (ctx.script.id !== script.$script.id)
          return;
        payload.events.push({
          type: "fn-call",
          fn: ctx.fn,
          args: ctx.args,
          at: Date.now()
        });
        syncScripts();
      });
      payload.$script = script.$script;
      payload.events.push({
        type: "status",
        status: "awaitingLoad",
        at: Date.now()
      });
      syncScripts();
    }
  }
  return script;
}
