import { useScript } from "./useScript.mjs";
import { isDoNotTrackEnabled, isRef, onNuxtReady, ref, toValue, watch } from "#imports";
export function useTrackingScript(input, options) {
  if (!options.ignoreDoNotTrack && isDoNotTrackEnabled())
    return;
  const instance = useScript(input, {
    ...options,
    trigger: "manual"
  });
  onNuxtReady(() => {
    const consented = ref(false);
    if (options?.consent) {
      if (typeof options?.consent === "boolean") {
        consented.value = true;
      } else if (options?.consent instanceof Promise) {
        options?.consent.then((res) => {
          consented.value = typeof res === "boolean" ? res : true;
        });
      } else if (isRef(options?.consent)) {
        watch(options.consent, (_val) => {
          const val = toValue(_val);
          if (typeof val === "boolean")
            consented.value = val;
        }, { immediate: true });
      }
    }
    watch(consented, (ready) => {
      ready && instance.$script.load();
    });
  });
  return instance;
}
